@@ -83,6 +83,10 @@ use constant {
         '立場新聞',
         '農傳媒',
         '報導者 The Reporter',
+        '眾新聞',
+        '中華日報',
+        '中華新聞雲',
+        '中視新聞',
     ],
 
     CATEGORY_NAMES => [
@@ -107,6 +111,11 @@ use constant {
         '運動',
         '重點新聞',
         '雜誌',
+        '社論',
+        '立場報道',
+        '苗中彰投雲',
+        '旅遊頻道',
+        '文化+',
     ],
 };
 
